/*
** Module   : PojoWebSocketHandler.java
** Abstract : create and register WebSockets POJO objects.
**
** Copyright (c) 2009-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131105 First version based on jetty 9.1
*/

package com.goldencode.p2j.ws;

import java.io.*;

import javax.servlet.*;
import javax.servlet.http.*;

import org.eclipse.jetty.server.*;
import org.eclipse.jetty.websocket.server.*;
import org.eclipse.jetty.websocket.servlet.*;

/**
 * This class is used to register and handle WebSockets POJO objects. 
 * <p>
 * Methods to create WebSockets:
 * <ul>
 *    <li>POJO WebSocket using annotations.</li>
 *    <li>Implements WebSocketListener interface.</li>
 *    <li>Extends WebSocketAdapter class.</li>
 * </ul> * 
 */
public class PojoWebSocketHandler 
extends WebSocketHandler
{
   /** WebSocket class */
   private Class<?> webSocketPojo;
   
   /** WebSocket target should be unique on the server context */ 
   private String webSocketTarget;

   /**
    * Constructor.
    * 
    * @param   webSocketTarget
    *          The WebSocket target string.
    *          This value should be unique on the WebSocket collection
    *          of handlers for the same server context.
    * @param   webSocketPojo
    *          The WebSocket POJO class.
    */
   public PojoWebSocketHandler(String webSocketTarget,
                               Class<?> webSocketPojo)
   {
      this.webSocketTarget = webSocketTarget;
      this.webSocketPojo = webSocketPojo;
   }

   @Override
   public void configure(WebSocketServletFactory wsServletFactory)
   {
      wsServletFactory.register(webSocketPojo);
   }

   @Override
   public void handle(String target, 
                      Request baseRequest,
                      HttpServletRequest request, 
                      HttpServletResponse response)
   throws IOException, 
          ServletException
   {
      if (!baseRequest.isHandled() && webSocketTarget.equals(target))
      {
         super.handle(target, baseRequest, request, response);
         baseRequest.setHandled(true);
      }
   }

}
