/*
** Module   : WebSocketAgent.java
** Abstract : A WebSocket client used for tests.
**
** Copyright (c) 2009-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131105 First version based on jetty 9.1
*/

package com.goldencode.p2j.ws.test;

import com.goldencode.p2j.cfg.*;
import com.goldencode.p2j.ws.*;

/**
 * A server Agent having an embedded web server example.
 * 
 * @author mag
 *
 */
public class WebSocketAgent
extends GenericWebServer
{

   /**
    * Embedded web server startup.
    * 
    * @param   config
    *          The bootstrap configuration structure used to build
    *          the server HTTPS SSL context.
    *          If <b>null</b> the server SSL context is used as default.
    *  
    * @throws  Exception
    *          If an error condition occur during the server startup.  
    */   
   public void initialize(BootstrapConfig config) 
   throws Exception
   {
      // Create a main page Handler
      MainPageHandler mainPage = new MainPageHandler(
         "/page", 
         "/com/goldencode/p2j/ws/test/index.html");      
      // Configure and start the embedded server
      setBootstrapConfig(config);
      setContextPath("/client");
      addHandler(mainPage);
      addWebSocketHandler("/test", WebSocketServlet.class);
      startup();            
   }
   
   /**
    * The server agents are lunched by a <code>ProcessBuilder</code> 
    * instance which create operating system processes.
    * Basically an agent is a Java application running on it own JVM.
    * The agent is based on a Java class that MUST have the main method.
    * 
    * @param   args command line arguments
    */
   public static void main(String[] args) 
   {      

   }
   
}
